"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const child_process_1 = require("child_process");
const fs_1 = require("fs");
const os_1 = require("os");
const path_1 = require("path");
function getPackageJSONContent(name) {
    const json = {
        name,
        version: "1.0.0",
        main: "index.js",
    };
    return JSON.stringify(json);
}
function createProjectDirectory() {
    return new Promise((resolve, reject) => {
        const path = fs_1.mkdtempSync(path_1.join(os_1.tmpdir(), "try-package-"));
        const name = "try-package-module";
        const packageJSON = getPackageJSONContent(name);
        fs_1.writeFileSync(path_1.join(path, "package.json"), packageJSON);
        resolve(path);
    });
}
exports.createProjectDirectory = createProjectDirectory;
function installModule(path, packages, flags) {
    return new Promise((resolve, reject) => {
        const args = ["install"];
        if (flags.registry) {
            args.push(`--registry=${flags.registry}`);
        }
        const npm = child_process_1.spawn("npm", args.concat(packages), {
            cwd: path,
            stdio: flags.verbose ? "inherit" : "ignore",
        });
        npm.on("close", (code) => {
            if (code === 0) {
                resolve();
            }
            else {
                const error = new Error(`npm install ${packages.join(" ")} exited with code ${code}`);
                reject(error);
            }
        });
    });
}
exports.installModule = installModule;
function supportReplAwait() {
    const version = Number(process.versions.node.split(".")[0]);
    return version >= 10;
}
exports.supportReplAwait = supportReplAwait;
